@@ -74,7 +74,7 @@
  *
  * TODO(Botan4) remove this
  */
-#define BOTAN_DISTRIBUTION_INFO "KaOS"
+#define BOTAN_DISTRIBUTION_INFO "unspecified"
 
 /**
  * @}
@@ -324,6 +324,7 @@
 #define BOTAN_HAS_TLS_12 20210608
 #define BOTAN_HAS_TLS_13 20241208
 #define BOTAN_HAS_TLS_13_PQC 20241208
+#define BOTAN_HAS_TLS_ASIO_STREAM 20181218
 #define BOTAN_HAS_TLS_CBC 20161008
 #define BOTAN_HAS_TLS_SESSION_MANAGER_SQL_DB 20141219
 #define BOTAN_HAS_TLS_SQLITE3_SESSION_MANAGER 20131128
@@ -360,6 +361,7 @@
 #define BOTAN_HAS_ARGON2_SSSE3 20220303
 #define BOTAN_HAS_BIGINT_MP 20151225
 #define BOTAN_HAS_BITVECTOR 20241202
+#define BOTAN_HAS_BOOST_ASIO 20131228
 #define BOTAN_HAS_CAMELLIA_GFNI 20250502
 #define BOTAN_HAS_CHACHA_AVX2 20180418
 #define BOTAN_HAS_CHACHA_AVX512 20230101
